@@ -53,6 +53,9 @@ def get_error_dictionary(schema, instance):
         else:
             # special case when error is not on a specific property
             message = root.get("errors", {}).get(error.schema_path[0])
-            d[error.schema_path[1]] = _replace_vars(root, message)
+            try:
+                d[error.schema_path[1]] = _replace_vars(root, message)
+            except IndexError as e:
+                d[error.schema_path[0]] = _replace_vars(root, message)
 
     return d
